@@ -11,7 +11,7 @@ class overwriteDialog : public QDialog
 {
     Q_OBJECT
 
-    friend class fourImages;
+    friend class wpNew;
 
 public:
     explicit overwriteDialog(QWidget *parent = 0);
