@@ -9,9 +9,9 @@ saveDialog::saveDialog(QWidget *parent) :
     ui->saveBtnBox->addButton("Save", QDialogButtonBox::YesRole);
     ui->saveBtnBox->addButton("Cancel", QDialogButtonBox::NoRole);
 
-    QRegExp nameRegExp("^[a-z0-9_-\\s]*$");
+    QRegExp nameRegExp("^[a-zA-Z0-9_-\\s]*$");
     // ^                From the beginning of the string
-    // [a-z0-9_-\s]     Only lowercase alphanumeric, _ and - and whitespace
+    // [a-zA-Z0-9_-\s]  Only alphanumeric, _ and - and whitespace
     // *                At least 0 characters
     // $                Until the end of the string
     ui->saveFileNameEdit->setValidator(new QRegExpValidator(nameRegExp, ui->saveFileNameEdit));
