@@ -19,6 +19,9 @@ wallPaeper::wallPaeper(QWidget *parent) :
             this, SLOT(newBtnClicked()));
     connect(ui->manBtn, SIGNAL(clicked()),
             this, SLOT(manBtnClicked()));
+
+    openNewWin = true;
+    openManWin = true;
 }
 
 
@@ -35,10 +38,19 @@ wallPaeper::~wallPaeper()
 
 
 void wallPaeper::newBtnClicked() {
-    newWin = new wpNew(this);
-    newWin->setAttribute(Qt::WA_Maemo5StackedWindow);
-    newWin->setAttribute(Qt::WA_DeleteOnClose);
-    newWin->show();
+    if(openNewWin == true) {
+        openNewWin = false;
+        openManWin = false;
+
+        newWin = new wpNew(this);
+        newWin->setAttribute(Qt::WA_Maemo5StackedWindow);
+        newWin->setAttribute(Qt::WA_DeleteOnClose);
+
+        connect(newWin, SIGNAL(destroyed()),
+                this, SLOT(openWinTrue()));
+
+        newWin->show();
+    }
 }
 
 
@@ -46,10 +58,28 @@ void wallPaeper::newBtnClicked() {
 
 
 void wallPaeper::manBtnClicked() {
-    manWin = new wpManager(this);
-    manWin->setAttribute(Qt::WA_Maemo5StackedWindow);
-    manWin->setAttribute(Qt::WA_DeleteOnClose);
-    manWin->show();
+    if(openManWin == true) {
+        openNewWin = false;
+        openManWin = false;
+
+        manWin = new wpManager(this);
+        manWin->setAttribute(Qt::WA_Maemo5StackedWindow);
+        manWin->setAttribute(Qt::WA_DeleteOnClose);
+
+        connect(manWin, SIGNAL(destroyed()),
+                this, SLOT(openWinTrue()));
+
+        manWin->show();
+    }
+}
+
+
+
+
+
+void wallPaeper::openWinTrue() {
+    openNewWin = true;
+    openManWin = true;
 }
 
 
@@ -74,7 +104,7 @@ void wallPaeper::createAbtDialog() {
     // Only create a new dialog if it hasn't been made yet
     if(abtDialogExists == false) {
         abtDialog = new aboutDialog(this);
-        abtDialog->setWindowTitle("Wallpaeper 0.4.1 for Nokia N900");
+        abtDialog->setWindowTitle("Wallpaeper 0.4.2 for Nokia N900");
 
         abtDialog->ui->aboutText1->adjustSize();
         abtDialog->ui->aboutText2->adjustSize();
