@@ -36,11 +36,14 @@ private:
 
     wpNew* newWin;
     wpManager* manWin;
+    bool openManWin;
+    bool openNewWin;
 
 public slots:
     void createAbtDialog();
     void newBtnClicked();
     void manBtnClicked();
+    void openWinTrue();
 };
 
 #endif // WALLPAEPER_H
