@@ -1,5 +1,7 @@
 #include "wpmanager.h"
 #include "ui_wpmanager.h"
+#include "wallpaeper.h"
+#include "ui_wallpaeper.h"
 
 #include <QMaemo5InformationBox>
 #include <QTextStream>
@@ -18,6 +20,7 @@ wpManager::wpManager(QWidget *parent) :
     connect(&watchDir, SIGNAL(directoryChanged(QString)),
             this, SLOT(updateList()));
 
+    openEditWin = true;
     delDialogIsMade = false;
     fileView = filenames;
     setupWPManMenuBar();
@@ -248,46 +251,55 @@ void wpManager::updatePrevs() {
 
 void wpManager::editCurrent() {
     if(checkSelected() == true) {
-        // Create a new wpNew window for editing
-        editWin = new wpNew(this);
-        editWin->setAttribute(Qt::WA_Maemo5StackedWindow);
-        editWin->setAttribute(Qt::WA_DeleteOnClose);
-        connect(editWin, SIGNAL(destroyed()),
-                this, SLOT(reselectAfterEdit()));
+        if(openEditWin == true) {
+            openEditWin = false;
+            // Create a new wpNew window for editing
+            editWin = new wpNew(this);
+            editWin->setAttribute(Qt::WA_Maemo5StackedWindow);
+            editWin->setAttribute(Qt::WA_DeleteOnClose);
+            connect(editWin, SIGNAL(destroyed()),
+                    this, SLOT(reselectAfterEdit()));
 
-        // Pass Name to editWin::nameEdit
-        editWin->ui->nameEdit->setText(imageSetList[ui->fileList->currentRow()][5]);
+            // Pass Name to editWin::nameEdit
+            editWin->ui->nameEdit->setText(imageSetList[ui->fileList->currentRow()][5]);
 
-        // Pass X-File# through 4 to editWin::imgPath[#]
-        for(i=0; i<4; i++) {
-            *editWin->imgPath[i] = imageSetList[ui->fileList->currentRow()][i+1];
-        }
-
-        // Put the "Invisible file" checkbox in the right state
-        if(QFileInfo(imageSetList[ui->fileList->currentRow()][0]).fileName().startsWith("."))
-            editWin->ui->visibChkbox->setChecked(true);
-        else
-            editWin->ui->visibChkbox->setChecked(false);
-
-        // Update previews, buttons, copytobuttons
-        for(i=0; i<4; i++) {
-            editWin->updateImgBtnPrev(i);
-            if(QFile(*editWin->imgPath[i]).exists() == true) {
-                editWin->imgPrevName[i]->setText(QFileInfo(*editWin->imgPath[i]).fileName());
-                editWin->setupCopyToBtn(i);
+            // Pass X-File# through 4 to editWin::imgPath[#]
+            for(i=0; i<4; i++) {
+                *editWin->imgPath[i] = imageSetList[ui->fileList->currentRow()][i+1];
             }
+
+            // Put the "Invisible file" checkbox in the right state
+            if(QFileInfo(imageSetList[ui->fileList->currentRow()][0]).fileName().startsWith("."))
+                editWin->ui->visibChkbox->setChecked(true);
+            else
+                editWin->ui->visibChkbox->setChecked(false);
+
+            // Update previews, buttons, copytobuttons
+            for(i=0; i<4; i++) {
+                editWin->updateImgBtnPrev(i);
+                if(QFile(*editWin->imgPath[i]).exists() == true) {
+                    editWin->imgPrevName[i]->setText(QFileInfo(*editWin->imgPath[i]).fileName());
+                    editWin->setupCopyToBtn(i);
+                }
+            }
+            editWin->updateSaveBtn();
+
+            // Pass the filename to editWin
+            editWin->saveFileName = QFileInfo(imageSetList[ui->fileList->currentRow()][0]).fileName();
+
+            // Before opening, save current row position
+            curRowBeforeEdit = ui->fileList->currentRow();
+
+            connect(editWin, SIGNAL(destroyed()),
+                    this, SLOT(openEditWinTrue()));
+
+            editWin->show();
         }
-        editWin->updateSaveBtn();
-
-        // Pass the filename to editWin
-        editWin->saveFileName = QFileInfo(imageSetList[ui->fileList->currentRow()][0]).fileName();
-
-        // Before opening, save current row position
-        curRowBeforeEdit = ui->fileList->currentRow();
-
-        editWin->show();
     }
 }
+void wpManager::openEditWinTrue() {
+    openEditWin = true;
+}
 
 
 
