@@ -28,9 +28,6 @@ public:
 public slots:
     void viewNames();
     void viewFilenames();
-//    void manPrevBtnClicked();
-//    void manEditBtnClicked();
-//    void manDelBtnClicked();
     void updatePrevs();
     void editCurrent();
     void confirmDelSet();
@@ -38,6 +35,7 @@ public slots:
     void itemChanged();
     void updateList();
     void reselectAfterEdit();
+    void openEditWinTrue();
 
 private:
     Ui::wpManager *ui;
@@ -95,6 +93,7 @@ private:
     } fileView;
 
     QFileSystemWatcher watchDir;
+    bool openEditWin;
 };
 
 #endif // WPMANAGER_H
